InterlaceType

Enum InterlaceType 

#[repr(u32)]
pub enum InterlaceType { UndefinedInterlace = 0, NoInterlace = 1, LineInterlace = 2, PlaneInterlace = 3, PartitionInterlace = 4, Unknown = 4_294_967_295, }
InterlaceType specifies the ordering of the red, green, and blue pixel information in the image. Interlacing is usually used to make image information available to the user faster by taking advantage of the space vs time tradeoff. For example, interlacing allows images on the Web to be recognizable sooner and satellite images to accumulate/render with image resolution increasing over time.

Use LineInterlace or PlaneInterlace to create an interlaced GIF or progressive JPEG image.

http://www.graphicsmagick.org/api/types.html#interlacetype

Variants



UndefinedInterlace = 0

Unset value.



NoInterlace = 1

Don’t interlace image (RGBRGBRGBRGBRGBRGB…)



LineInterlace = 2

Use scanline interlacing (RRR…GGG…BBB…RRR…GGG…BBB…)



PlaneInterlace = 3

Use plane interlacing (RRRRRR…GGGGGG…BBBBBB…)



PartitionInterlace = 4

Similar to plane interlaing except that the different planes are saved to individual files (e.g. image.R, image.G, and image.B)



Unknown = 4_294_967_295